const path = require('path')
const webpack = require('webpack')
const HtmlWebpackPlugin = require('html-webpack-plugin')
const CopyWebpackPlugin = require('copy-webpack-plugin')
const { projectPath } = require('../utils')
const appConfig = require('../utils/get-app-config')

const config = {
  ...appConfig.webpack,
  mode: 'none',
  devtool: '#eval-source-map',
  output: {
    filename: '[name].js',
    path: `${projectPath}/public`,
  },
  resolve: {
    alias: {
      'vue$': 'vue/dist/vue.esm.js'
    }
  },
  plugins: [
    new HtmlWebpackPlugin({
      filename: 'index.html',
      template: path.join(projectPath, 'index.template.ejs'),
      inject: true,
    }),
    new webpack.DllReferencePlugin({
      manifest: require(`${projectPath}/vendor_manifest.json`)
    }),
    new CopyWebpackPlugin([
      {
        from: `${projectPath}/static`,
        to: 'static',
      }
    ])
  ],
}

module.exports = config